namespace efl { namespace ui { namespace text { 
inline ::efl::eolian::return_traits<bool>::type Interactive::selection_allowed_get() const
{
   Eina_Bool __return_value =  ::efl_ui_text_interactive_selection_allowed_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Interactive::selection_allowed_set( ::efl::eolian::in_traits<bool>::type allowed) const
{
    ::efl_ui_text_interactive_selection_allowed_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(allowed));
}
inline ::efl::eolian::return_traits<void>::type Interactive::selection_cursors_get( ::efl::eolian::out_traits< ::efl::canvas::text::Cursor>::type start,  ::efl::eolian::out_traits< ::efl::canvas::text::Cursor>::type end) const
{
    ::Efl_Canvas_Text_Cursor* __out_param_start = {};
    ::Efl_Canvas_Text_Cursor* __out_param_end = {};
    ::efl_ui_text_interactive_selection_cursors_get(this->_eo_ptr()
      , & __out_param_start
      , & __out_param_end);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits< ::efl::canvas::text::Cursor>::type,  ::Efl_Canvas_Text_Cursor*>(start, __out_param_start);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits< ::efl::canvas::text::Cursor>::type,  ::Efl_Canvas_Text_Cursor*>(end, __out_param_end);
}
inline ::efl::eolian::return_traits<bool>::type Interactive::multiline_get() const
{
   Eina_Bool __return_value =  ::efl_ui_text_interactive_multiline_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Interactive::multiline_set( ::efl::eolian::in_traits<bool>::type enabled) const
{
    ::efl_ui_text_interactive_multiline_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(enabled));
}
inline ::efl::eolian::return_traits<bool>::type Interactive::editable_get() const
{
   Eina_Bool __return_value =  ::efl_ui_text_interactive_editable_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Interactive::editable_set( ::efl::eolian::in_traits<bool>::type editable) const
{
    ::efl_ui_text_interactive_editable_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(editable));
}
} } } 
namespace eo_cxx {
namespace efl { namespace ui { namespace text { 
inline ::efl::eolian::return_traits<bool>::type Interactive::selection_allowed_get() const
{
   Eina_Bool __return_value =  ::efl_ui_text_interactive_selection_allowed_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Interactive::selection_allowed_set( ::efl::eolian::in_traits<bool>::type allowed) const
{
    ::efl_ui_text_interactive_selection_allowed_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(allowed));
}
inline ::efl::eolian::return_traits<void>::type Interactive::selection_cursors_get( ::efl::eolian::out_traits< ::efl::canvas::text::Cursor>::type start,  ::efl::eolian::out_traits< ::efl::canvas::text::Cursor>::type end) const
{
    ::Efl_Canvas_Text_Cursor* __out_param_start = {};
    ::Efl_Canvas_Text_Cursor* __out_param_end = {};
    ::efl_ui_text_interactive_selection_cursors_get(this->_eo_ptr()
      , & __out_param_start
      , & __out_param_end);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits< ::efl::canvas::text::Cursor>::type,  ::Efl_Canvas_Text_Cursor*>(start, __out_param_start);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits< ::efl::canvas::text::Cursor>::type,  ::Efl_Canvas_Text_Cursor*>(end, __out_param_end);
}
inline ::efl::eolian::return_traits<bool>::type Interactive::multiline_get() const
{
   Eina_Bool __return_value =  ::efl_ui_text_interactive_multiline_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Interactive::multiline_set( ::efl::eolian::in_traits<bool>::type enabled) const
{
    ::efl_ui_text_interactive_multiline_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(enabled));
}
inline ::efl::eolian::return_traits<bool>::type Interactive::editable_get() const
{
   Eina_Bool __return_value =  ::efl_ui_text_interactive_editable_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Interactive::editable_set( ::efl::eolian::in_traits<bool>::type editable) const
{
    ::efl_ui_text_interactive_editable_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(editable));
}
inline efl::ui::text::Interactive::operator ::efl::ui::text::Interactive() const { return *static_cast< ::efl::ui::text::Interactive const*>(static_cast<void const*>(this)); }
inline efl::ui::text::Interactive::operator ::efl::ui::text::Interactive&() { return *static_cast< ::efl::ui::text::Interactive*>(static_cast<void*>(this)); }
inline efl::ui::text::Interactive::operator ::efl::ui::text::Interactive const&() const { return *static_cast< ::efl::ui::text::Interactive const*>(static_cast<void const*>(this)); }
} } } }

